# rtprio

rtprio is a Python interface for rtprio(2) in FreeBSD and DragonflyBSD. Currently, these are the only two platforms where rtprio(2) actually exists (to my knowledge). Feel free to inform me differently or create a PR to include support for other platforms.
